<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2011 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+
/*
Language Name: Srpski [SR]
Version: 2.3.0
Language URI: http://piwigo.org/ext/extension_view.php?eid=435
Author: Piwigo team
Author URI: http://piwigo.org
*/

// Langage informations
$lang_info['language_name'] = 'Srpski';
$lang_info['country'] = 'Srbija';
$lang_info['direction'] = 'ltr';
$lang_info['code'] = 'sh';
$lang_info['zero_plural'] = true;

$lang['%.2f (rated %d times)'] = '%.2f (ocenjeno %d puta)';
$lang['%d Kb'] = '%d Kb';
$lang['%d album updated'] = '%d kategorija obnovljena';
$lang['%d albums updated'] = '%d kategorije obnovljene';
$lang['%d comment to validate'] = '%d komentar za overu';
$lang['%d comments to validate'] = '%d komentari za overu';
$lang['%d new comment'] = '%d novi komentar';
$lang['%d new comments'] = '%d novi komentari';
$lang['%d comment'] = '%d komentar';
$lang['%d comments'] = '%d komentari';
$lang['%d hit'] = '%d poseta';
$lang['%d hits'] = '%d poseta';
$lang['%d new photo'] = '%d nova slika';
$lang['%d new photos'] = '%d nove slike';
$lang['%d new user'] = '%d novi korisnik';
$lang['%d new users'] = '%d novi korisnici';
$lang['About'] = 'O...';
$lang['All tags'] = 'Svi tagovi';
$lang['Any tag'] = 'Bilo koji tag';
$lang['At least one listed rule must be satisfied.'] = 'Najmanje jedno od navedenih pravila mora biti zadovoljeno.';
$lang['At least one tag must match'] = 'Najmanje jedan tag se mora poklapati';
$lang['Author'] = 'Autor';
$lang['Average rate'] = 'Prosečna ocena';
$lang['Albums'] = 'Kategorije';
$lang['Album'] = 'Kategorija';
$lang['Close this window'] = 'Zatvori prozor';
$lang['Complete RSS feed (photos, comments)'] = 'Potpuni RSS izvori (slike, komentari)';
$lang['Confirm Password'] = 'Potvrdi Lozinku';
$lang['Connection settings'] = 'Podešavanja povezivanja';
$lang['Login'] = 'Prijava';
$lang['Contact webmaster'] = 'Pišite webmaster-u';
$lang['Create a new account'] = 'Napravi novi nalog';
$lang['Created on'] = 'Napravljen na';
$lang['Creation date'] = 'Datum izrade';
$lang['Current password is wrong'] = 'Trenutna lozinka je neispravna';
$lang['Dimensions'] = 'Veličine';
$lang['Display'] = 'Prikaz';
$lang['Each listed rule must be satisfied.'] = 'Svako navedeno pravilo mora biti zadovoljeno.';
$lang['Email address is missing. Please specify an email address.'] = 'Nedostaje E-mail adresa';
$lang['Email address'] = 'E-mail adresa';
$lang['Enter your personnal informations'] = 'Upišite svoje lične podatke';
$lang['Error sending email'] = 'Greška prilikom slanja e-mail poruke';
$lang['File name'] = 'Naziv datoteke';
$lang['File'] = 'Datoteka';
$lang['Filesize'] = 'Veličina datoteke';
$lang['Filter and display'] = 'Filter i prikaz';
$lang['Filter'] = 'Filter';
$lang['Forgot your password?'] = 'Zaboravili ste lozinku?';
$lang['Go through the gallery as a visitor'] = 'Pregledajte galeriju kao posetioc';
$lang['Help'] = 'Pomoć';
$lang['Identification'] = 'Prijava';
$lang['Photos only RSS feed'] = 'RSS izvor samo za slike';
$lang['Keyword'] = 'Ključna riječ';
$lang['Links'] = 'Linkovi';
$lang['N/A'] = 'N/D';
$lang['New on %s'] = 'Novi na on %s';
$lang['New password confirmation does not correspond'] = 'Potvrda nove lozinke ne odgovara';
$lang['Notification'] = 'Obaveštenje';
$lang['Number of items'] = 'Broj stavki';
$lang['Original dimensions'] = 'Izvorne veličine';
$lang['Password forgotten'] = 'Zaboravljena lozinka';
$lang['Password'] = 'Lozinka';
$lang['Post date'] = 'Datum objave';
$lang['Posted on'] = 'Objavljeno u';
$lang['Profile'] = 'Profil';
$lang['Quick connect'] = 'Brza veza';
$lang['RSS feed'] = 'RSS izvor';
$lang['Rate'] = 'Ocena';
$lang['Register'] = 'Upišite se';
$lang['Registration'] = 'Registracija';
$lang['Related tags'] = 'Povezani tagovi';
$lang['Reset'] = 'Poništi';
$lang['Retrieve password'] = 'Vrati lozinku';
$lang['Search rules'] = 'Pravila pretrage';
$lang['Search tags'] = 'Tagovi pretrage';
$lang['Search'] = 'Pretraživanje';
$lang['display available tags'] = 'Pogledaj dostupne tagove';
$lang['Since'] = 'Od';
$lang['Sort by'] = 'Složeno po';
$lang['Sort order'] = 'Redosled slaganja';
$lang['Tag'] = 'Oznaka';
$lang['Tags'] = 'Tagovi';
$lang['The RSS notification feed provides notification on news from this website : new photos, updated albums, new comments. Use a RSS feed reader.'] = 'RSS obavijesni izvor omogućava obaveštavanje o novostima sa ovog web mesta : nove slike, obnovljene kategorije, nove komentare. Koristite čitač RSS izvora.';
$lang['Unknown feed identifier'] = 'Nepoznata oznaka izvora';
$lang['User comments'] = 'Korisnički komentari';
$lang['Username'] = 'Korisničko ime';
$lang['Visits'] = 'Poseta';
$lang['Webmaster'] = 'Webmaster';
$lang['Week %d'] = 'Nedelja %d';
$lang['About Piwigo'] = 'O Piwigo-u';
$lang['You are not authorized to access the requested page'] = 'Niste ovlašteni za pristup zatraženoj stranici';
$lang['add to caddie'] = 'dodaj u fioku';
$lang['add this photo to your favorites'] = 'dodaj ovu sliku u omiljene';
$lang['Administration'] = 'Administracija';
$lang['all'] = 'sve';
$lang['ascending'] = 'uzlazno';
$lang['author(s) : %s'] = 'autor(i) : %s';
$lang['Expand all albums'] = 'Proširi sve kategorije';
$lang['posted after %s (%s)'] = 'objavljeno posle %s (%s)';
$lang['posted before %s (%s)'] = 'objavljeno pre %s (%s)';
$lang['posted between %s (%s) and %s (%s)'] = 'objavljeno između %s (%s) i %s (%s)';
$lang['posted on %s'] = 'objavljeno na %s';
$lang['Best rated'] = 'Najbolje ocenjeno';
$lang['display best rated photos'] = 'prikaz najbolje ocenjenih stavki';
$lang['caddie'] = 'Fioka';
$lang['Calendar'] = 'Kalendar';
$lang['All'] = 'Sve';
$lang['display each day with photos, month per month'] = 'prikaz svakog dana sa slikama, mesec po mesec';
$lang['View'] = 'Pogledaj';
$lang['chronology_monthly_calendar'] = 'Mesečni kalendar';
$lang['chronology_monthly_list'] = 'Mesečni popis';
$lang['chronology_weekly_list'] = 'Nedeljni popis';
$lang['Click here if your browser does not automatically forward you'] = 'Kliknite ovde ako niste automatski prebačeni';
$lang['comment date'] = 'datum komentara';
$lang['Comment'] = 'Komentar';
$lang['Your comment has been registered'] = 'Vaš je komentar upisan';
$lang['Anti-flood system : please wait for a moment before trying to post another comment'] = 'Anti-flood sistem : molimo sačekajte malo pre objave novog komentara';
$lang['Your comment has NOT been registered because it did not pass the validation rules'] = 'Vaš komentar NIJE upisan jer nije prošao pravila overe';
$lang['An administrator must authorize your comment before it is visible.'] = 'Administrator mora odobriti vaš komentar pre objave.';
$lang['This login is already used by another user'] = 'Ovo korisničko ime se već koristi';
$lang['Comments'] = 'Komentari';
$lang['Add a comment'] = 'Dodaj komentar';
$lang['created after %s (%s)'] = 'napravljen nakon %s (%s)';
$lang['created before %s (%s)'] = 'napravljen prije %s (%s)';
$lang['created between %s (%s) and %s (%s)'] = 'napravljen između %s (%s) i %s (%s)';
$lang['created on %s'] = 'napravljen na %s';
$lang['Customize'] = 'Podesi';
$lang['Your Gallery Customization'] = 'Podešavanje Vaše Galerije ';
$lang['day'][0] = 'Nedelja';
$lang['day'][1] = 'Ponedjeljak';
$lang['day'][2] = 'Utorak';
$lang['day'][3] = 'Sreda';
$lang['day'][4] = 'Četvrtak';
$lang['day'][5] = 'Petak';
$lang['day'][6] = 'Subota';
$lang['Default'] = 'Podrazumevano';
$lang['delete this photo from your favorites'] = 'uklonite ovu sliku iz omiljenih';
$lang['Delete'] = 'Ukloni';
$lang['descending'] = 'silazno';
$lang['download'] = 'preuzmi';
$lang['download this file'] = 'preuzmi ovu sliku';
$lang['edit'] = 'uredi';
$lang['wrong date'] = 'pogrešan datum';
$lang['excluded'] = 'isključeno';
$lang['Your favorites'] = 'Moji omiljeni';
$lang['display your favorites photos'] = 'prikaz mojih omiljenih slika';
$lang['Favorites'] = 'Omiljeni';
$lang['First'] = 'Prvi';
$lang['The gallery is locked for maintenance. Please, come back later.'] = 'Galerija je zaključana zbog održavanja. Molimo, navratite kasnije.';
$lang['Page generated in'] = 'Stranica izrađena u ';
$lang['guest'] = 'gost';
$lang['Hello'] = 'Pozdrav';
$lang['available for administrators only'] = 'dostupno samo administratorima';
$lang['display this album'] = 'prikazuje slike u glavnoj kategoriji';
$lang['display last user comments'] = 'Pregled zadnjih korisničkih komentara';
$lang['customize the appareance of the gallery'] = 'podesite izgled vaše galerije';
$lang['search'] = 'pretraži';
$lang['Home'] = 'Početna';
$lang['in this album'] = 'u ovoj kategoriji';
$lang['in %d sub-album'] = 'u %d podkategoriji';
$lang['in %d sub-albums'] = 'u %d podkategorijama';
$lang['included'] = 'uključeno';
$lang['Invalid password!'] = 'Pogrešna lozinka!';
$lang['Language']='Jezik';
$lang['last %d days'] = 'zadnjih %d dana';
$lang['Last'] = 'Zadnji';
$lang['Logout'] = 'Odjava';
$lang['E-mail address'] = 'E-mail adresa';
$lang['obligatory'] = 'obvezno';
$lang['Maximum photo height'] = 'Najveća dozvoljena visina slika';
$lang['Maximum height must be a number superior to 50'] = 'Najveća visina mora biti broj veći od 50';
$lang['Maximum photo width'] = 'Najveća dozvoljena širina slika';
$lang['Maximum width must be a number superior to 50'] = 'Najveća širina mora biti broj veći od 50';
$lang['display a calendar by creation date'] = 'prikaz kalendara po datumu izrade';
$lang['display all photos in all sub-albums'] = 'prikaz svih stavki u svim podkategorijama';
$lang['return to normal view mode'] = 'povratak u uobičajeni način pregleda';
$lang['display a calendar by posted date'] = 'prikaz kalendara po datumu objave';
$lang['month'][10] = 'Oktobar';
$lang['month'][11] = 'Novembar';
$lang['month'][12] = 'Decembar';
$lang['month'][1] = 'Januar';
$lang['month'][2] = 'Februar';
$lang['month'][3] = 'Mart';
$lang['month'][4] = 'April';
$lang['month'][5] = 'Maj';
$lang['month'][6] = 'Jun';
$lang['month'][7] = 'Jul';
$lang['month'][8] = 'Avgust';
$lang['month'][9] = 'Septembar';
$lang['Most visited'] = 'Najposjećenije';
$lang['display most visited photos'] = 'prikaz najposjećenijih slika';
$lang['The number of photos per page must be a not null scalar'] = 'broj slika po stranici mora biti celobrojna vrednost';
$lang['Number of photos per page'] = 'Broj slika po stranici';
$lang['Unknown identifier'] = 'Nepoznata oznaka';
$lang['New password'] = 'Nova lozinka';
$lang['Rate this photo'] = 'Oceni ovu sliku';
$lang['Next'] = 'Sledeći';
$lang['no rate'] = 'bez ocene';
$lang['Photos posted within the last %d day.'] = 'Stavke objavljene u zadnjem %d danu.';
$lang['Photos posted within the last %d days.'] = 'Stavke objavljene u zadnjih %d dana.';
$lang['password updated'] = 'lozinka obnovljena';
$lang['Recent period must be a positive integer value'] = 'Razdoblje mora biti pozitivna celobrojna vrednost';
/* DEPRECATED USED IN comments.php FOR image_id ? */ $lang['photo'] = 'slika';
$lang['Click on the photo to see it in high definition'] = 'Klikni na sliku za pregled u visokoj rezoluciji';
$lang['Show file metadata'] = 'Prikaži meta podatke zapisa';
$lang['Powered by'] = 'Urađeno u';
$lang['Preferences'] = 'Podešenja';
$lang['Previous'] = 'Prethodni';
$lang['Random photos'] = 'Slike po slučajnom izboru';
$lang['display a set of random photos'] = 'prikaz slika po slučajnom izboru';
$lang['Recent albums'] = 'Nedavne kategorije';
$lang['display recently updated albums'] = 'prikaz nedavno obnovljenih kategorija';
$lang['Recent period'] = 'Nedavno razdoblje';
$lang['Recent photos'] = 'Nedavne slike';
$lang['display most recent photos'] = 'prikaz najnovijih slika';
$lang['Redirection...'] = 'Preusmeravanje...';
$lang['Please, enter a login'] = 'Molimo, prijavite se';
$lang['login mustn\'t end with a space character'] = 'prijava ne sme završavati razmakom';
$lang['login mustn\'t start with a space character'] = 'prijava ne sme počinjati razmakom';
$lang['this login is already used'] = 'ovo korisničko ime se već koristi';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = 'e-mail adresa mora biti oblika xxx@yyy.eee (npr : korisnik@stranica.org)';
$lang['please enter your password again'] = 'molimo unesite lozinku ponovo';
$lang['Auto login'] = 'Upamti me';
$lang['remove this tag from the list'] = 'ukloni  ovaj tag iz popisa';
$lang['representative'] = 'predstavnik';
$lang['Search for Author'] = 'Pretraživanje po Autoru';
$lang['Search in albums'] = 'Pretraživanje u Kategorijama';
$lang['Search by Date'] = 'Pretraživanje po Datumu';
$lang['Date'] = 'Datum';
$lang['End-Date'] = 'Krajnji Datum';
$lang['Kind of date'] = 'Vrsta datuma';
$lang['Search for words'] = 'Pretraživanje po rečima';
$lang['Search for all terms'] = 'Pretraživanje po svim kriterijumima ';
$lang['Search for any terms'] = 'Pretraživanje po bilo kojem kriterijumu';
$lang['Empty query. No criteria has been entered.'] = 'Prazna pretraga. Nije unešeno ni jedno polje.';
$lang['Search Options'] = 'Mogućnosti Pretraživanja';
$lang['Search results'] = 'Rezultati pretraživanja';
$lang['Search in sub-albums'] = 'Pretraživanje u podkategorijama';
$lang['searched words : %s'] = 'tražene reči : %s';
$lang['Contact'] = 'Kontakt';
$lang['set as album representative'] = 'postavi za predstavnika kategorije';
$lang['Show number of comments'] = 'Prikaži broj komentara';
$lang['Show number of hits'] = 'Prikaži broj poseta';
$lang['slideshow'] = 'klizni prikaz';
$lang['stop the slideshow'] = 'zaustavi klizni prikaz';
$lang['Specials'] = 'Posebne kategorije';
$lang['SQL queries in'] = 'SQL upit u ';
$lang['display only recently posted photos'] = 'prikaz samo nedavno objavljenih slika';
$lang['return to the display of all photos'] = 'povratak u prikaz svih slika';
$lang['the beginning'] = 'početak';
$lang['Interface theme'] = 'tema';
$lang['Thumbnails'] = 'Sličice';
$lang['Menu'] = 'Izbornik';
$lang['A comment on your site'] = 'Komentar na Vašem web mestu';
$lang['today'] = 'danas';
$lang['Update your rating'] = 'Obnovite svoju ocenu';
$lang['wrong filename'] = 'pogrešan naziv datoteke';
$lang['the username must be given'] = 'mora se upisati korisničko ime';
$lang['useful when password forgotten'] = 'korisno kada se zaboravi lozinka';
$lang['Quick search'] = 'Brzo pretraživanje';
$lang['Connected user: %s'] = 'Povezani korisnik: %s';
$lang['IP: %s'] = 'IP: %s';
$lang['Browser: %s'] = 'Pretraživač: %s';
$lang['Author: %s'] = 'Autor: %s';
$lang['Comment: %s'] = 'Komentar: %s';
$lang['Comment by %s'] = 'Komentarisao-la %s';
$lang['User: %s'] = 'Korisnik: %s';
$lang['Email: %s'] = 'E-mail: %s';
$lang['Admin: %s'] = 'Administrator: %s';
$lang['Registration of %s'] = 'Prijava od %s';
$lang['Album: %s'] = 'Kategorija: %s';
$lang['Bad status for user "guest", using default status. Please notify the webmaster.'] = 'Loš status za korisnika "guest", koristi se podrazumevani status. Molimo obavestite webmaster-a.';
$lang['this email address is already in use'] = 'korisnik već koristi ovu e-mail adresu';
$lang['Album results for'] = 'Rezultati kategorije za ';
$lang['Tag results for'] = 'Rezultati tagova za';
$lang['from %s to %s'] = 'od %s do %s';
$lang['Play of slideshow'] = 'Pokreni klizni prikaz';
$lang['Pause of slideshow'] = 'Zaustavi klizni prikaz';
$lang['Repeat the slideshow'] = 'Ponovi klizni prikaz';
$lang['Not repeat the slideshow'] = 'Ne ponavljaj klizni prikaz';
$lang['Reduce diaporama speed'] = 'Smanji brzinu ';
$lang['Accelerate diaporama speed'] = 'Povećaj brzinu ';
$lang['Submit'] = 'Pošalji';
$lang['Yes'] = 'Da';
$lang['No'] = 'Ne';
$lang['%d photo']='%d slika';
$lang['%d photos']='%d slike';
$lang['%d photo is also linked to current tags'] = '%d slika takođe povezana sa trenutnim tagovima';
$lang['%d photos are also linked to current tags'] = '%d slike takođe povezana sa trenutnim tagovima';
$lang['display photos linked to this tag'] = 'Pregledaj slike povezane samo sa ovim tag-om';
$lang['photos posted during the last %d days'] = 'slike objavljene tokom zadnjih %d dana';
$lang['Piwigo Help'] = 'Piwigo Pomoć';
$lang['Rank'] = 'Redosled';
$lang['group by letters'] = 'složeno po slovima';
$lang['letters'] = 'slova';
$lang['show tag cloud'] = 'prikaži tag oblak';
$lang['cloud'] = 'oblak';
$lang['Reset to default values'] = 'Vrati na podrazumevane vrednosti';
$lang['delete all photos from your favorites'] = 'obriši sve slike iz Omiljeni';
$lang['Sent by'] = 'Poslao';
$lang['Cookies are blocked or not supported by your browser. You must enable cookies to connect.'] = 'Cookies su blokirani ili nisu podržani od Vašeg pretraživača. Morate omogućiti cookies da bi se logovali.';
$lang['edit this comment'] = 'uredi ovaj komentar';
$lang['Edit a comment'] = 'Uredi komentar';
$lang['Are you sure?'] = 'Jeste li sigurni?';
$lang['(!) This comment requires validation'] = '(!) Ovaj komentar zahteva overu';
$lang['Welcome'] = 'Dobrodošli';
$lang['Welcome to your Piwigo photo gallery!'] = 'Dobrodošli u Vašu Piwigo foto galeriju!';
$lang['... or browse your empty gallery'] = '... ili pretraži Vašu praznu galeriju';
$lang['... or please deactivate this message, I will find my way by myself'] = '... ili isključite ovu poruku, uradiću to na svoj način';
$lang['Hello %s, your Piwigo photo gallery is empty!'] = 'Zdravo %s, Vaša Piwigo foto galerija je prazna!';
$lang['I want to add photos'] = 'Želim da dodam fotografije';
$lang['Manage this user comment: %s'] = 'Uredi komentare ovog korisnika: %s';
$lang['This author modified following comment:'] = 'Ovaj autor je menjao tekući komentar:';
$lang['This author removed the comment with id %d'] = 'Ovaj autor je uklonio komentar sa identifikacijom %d';
$lang['delete this comment'] = 'obriši ovaj komentar';
$lang['validate this comment'] = 'Overi ovaj komentar';
$lang['html tags are not allowed in login'] = 'html oznake nisu dozvoljene prilikom logovanja';
?>